==> haskell-uuid-types-1.0.3-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-C70jVBzardLFMfav9eGqfw
key: uuid-types-1.0.3-C70jVBzardLFMfav9eGqfw
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder
abi: 504a952fe31bef83911bc22e1ae25dc9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-C70jVBzardLFMfav9eGqfw
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy=6e4b4a70e10d525b7db51e3859aab169
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-types-1.0.3-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.3
id: uuid-types-1.0.3-C31qoQYhIFY6Z1J9cF82aJ
key: uuid-types-1.0.3-C31qoQYhIFY6Z1J9cF82aJ
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
indefinite: False
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder
abi: 08f6e907167c784bad61f1a24ddf421d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/uuid-types-1.0.3
hs-libraries: HSuuid-types-1.0.3-C31qoQYhIFY6Z1J9cF82aJ
depends:
    base-4.10.1.0 binary-0.8.5.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             binary-0.8.5.1=33c677d3ced9a5afbc7b354509494653
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
